// This file just generates the RTD badge for use on docs not using the RTD theme.

@import wyrm_core/wy_variables
@import bourbon
@import neat
@import wyrm_core/mixin
@import wyrm_core/grid_settings
@import badge_font_awesome_mini
@import badge
